### This display all variables

(see src/hatch_ci/tools.py:get_data)

- **ctx.version**  0.1.3b39
- **ctx.current**  0.1.3
- **ctx.ref**      refs/heads/beta/0.1.3
- **ctx.branch**   beta/0.1.3
- **ctx.sha**      8d8c24326a3a4deb8366080588796f96814c5a55
- **ctx.build**    39
- **ctx.runid**    6592372603
- **ctx.workflow** beta